@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 import argparse
+import os
 import sys
 
 from codex_processor.utils import parse_json
@@ -84,6 +85,7 @@ def main():
     assert args.output_format
 
     health_check_result = health_check_wrapper()
+    os.environ.setdefault("PYPANDOC_PANDOC", health_check_result.pandoc_path)
 
     pw = ProcessorWrapper(
         source_path=args.source_path,
